==> kubernetes-model-rbac-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/rbac/SubjectFluent.java <==
package io.fabric8.kubernetes.api.model.rbac;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface SubjectFluent<A extends SubjectFluent<A>> extends Fluent<A> {


    public String getApiGroup();
    public A withApiGroup(String apiGroup);
    public Boolean hasApiGroup();
    public A withNewApiGroup(StringBuilder arg1);
    public A withNewApiGroup(int[] arg1,int arg2,int arg3);
    public A withNewApiGroup(char[] arg1);
    public A withNewApiGroup(StringBuffer arg1);
    public A withNewApiGroup(byte[] arg1,int arg2);
    public A withNewApiGroup(byte[] arg1);
    public A withNewApiGroup(char[] arg1,int arg2,int arg3);
    public A withNewApiGroup(byte[] arg1,int arg2,int arg3);
    public A withNewApiGroup(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiGroup(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public String getNamespace();
    public A withNamespace(String namespace);
    public Boolean hasNamespace();
    public A withNewNamespace(StringBuilder arg1);
    public A withNewNamespace(int[] arg1,int arg2,int arg3);
    public A withNewNamespace(char[] arg1);
    public A withNewNamespace(StringBuffer arg1);
    public A withNewNamespace(byte[] arg1,int arg2);
    public A withNewNamespace(byte[] arg1);
    public A withNewNamespace(char[] arg1,int arg2,int arg3);
    public A withNewNamespace(byte[] arg1,int arg2,int arg3);
    public A withNewNamespace(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewNamespace(String arg1);
}

==> kubernetes-model-rbac-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/rbac/SubjectFluent.java <==
package io.fabric8.kubernetes.api.model.rbac;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface SubjectFluent<A extends SubjectFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getApiGroup();
    public A withApiGroup(String apiGroup);
    public Boolean hasApiGroup();
    public A withNewApiGroup(StringBuilder arg1);
    public A withNewApiGroup(int[] arg1,int arg2,int arg3);
    public A withNewApiGroup(char[] arg1);
    public A withNewApiGroup(StringBuffer arg1);
    public A withNewApiGroup(byte[] arg1,int arg2);
    public A withNewApiGroup(byte[] arg1);
    public A withNewApiGroup(char[] arg1,int arg2,int arg3);
    public A withNewApiGroup(byte[] arg1,int arg2,int arg3);
    public A withNewApiGroup(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiGroup(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public String getNamespace();
    public A withNamespace(String namespace);
    public Boolean hasNamespace();
    public A withNewNamespace(StringBuilder arg1);
    public A withNewNamespace(int[] arg1,int arg2,int arg3);
    public A withNewNamespace(char[] arg1);
    public A withNewNamespace(StringBuffer arg1);
    public A withNewNamespace(byte[] arg1,int arg2);
    public A withNewNamespace(byte[] arg1);
    public A withNewNamespace(char[] arg1,int arg2,int arg3);
    public A withNewNamespace(byte[] arg1,int arg2,int arg3);
    public A withNewNamespace(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewNamespace(String arg1);
}
